@@ -1,6 +1,6 @@
 use strict;
 package Web::Authenticate;
-$Web::Authenticate::VERSION = '0.002';
+$Web::Authenticate::VERSION = '0.003';
 use Mouse;
 use Carp;
 use Web::Authenticate::Cookie::Handler;
@@ -304,7 +304,7 @@ Web::Authenticate - Allows web authentication using cookies and a storage engine
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
@@ -371,7 +371,7 @@ version 0.002
         age => 22,
         address => '123 Hopper Ln, Austin TX 78705',
     };
-    my $create_user_result = $web_authenticate->create_user(username => $username, password => $password, $user_values);
+    my $create_user_result = $web_authenticate->create_user(username => $username, password => $password, user_values => $user_values);
 
     if ($create_user_result->success) {
         print "Created user " . $create_user_result->user->id . "\n";
